@@ -36,7 +36,9 @@ DespotifyWrap::DespotifyWrap() {
 
     this->lastlist=NULL;
     this->playlists=NULL;
-    this->pending_list=NULL;
+    this->pending_search=NULL;
+    this->pending_playlist=NULL;
+    this->pending_album=NULL;
 
 }
 
@@ -49,7 +51,6 @@ DespotifyWrap::~DespotifyWrap() {
 bool DespotifyWrap::Authenticate(char *user, char *pass) {
 
     if (!despotify_authenticate(this->ds, user, pass)) {
-        qDebug() << "Authentication failed: " << (char*)despotify_get_error(ds);
         //despotify_exit(ds);
         return false;
     } else {
@@ -82,26 +83,31 @@ playlist* DespotifyWrap::GetPlaylists() {
     return this->playlists;
 }
 
-void DespotifyWrap::Play(int list_offset) {
+void DespotifyWrap::GetAlbumFromID(unsigned char* id) {
+    this->album = despotify_get_album(this->ds,(char*)id);
+}
 
+const uchar* DespotifyWrap::GetImage(char* id,int* img_len) {
+    return (const uchar*)despotify_get_image(this->ds,id,img_len);
+}
+
+
+
+void DespotifyWrap::Play(int list_offset) {
     /* Make sure we have a playlist to play from */
-    if(this->lastlist) {
-        track *t = this->lastlist->tracks;
-        if(t) {
-            this->current_offset = list_offset;
-            for (int i=0; i<list_offset && t; i++) {
-                t = t->next;
-                this->current_offset = i+1;
-            }
-            if (t&&t->playable) {
-                /* Start playing the new song */
-                this->player->NewSong(this->ds, t, true);
-            }
-        } else {
-            qDebug() << "No tracks to play there mate";
+    track *t = this->lastlist;
+    if(t) {
+        this->current_offset = list_offset;
+        for (int i=0; i<list_offset && t; i++) {
+            t = t->next;
+            this->current_offset = i+1;
+        }
+        if (t&&t->playable) {
+            /* Start playing the new song */
+            this->player->NewSong(this->ds, t, true);
         }
     } else {
-        qDebug() << "Tried to play a song from an invalid playlist";
+        qDebug() << "No tracks to play there mate";
     }
 }
 
@@ -116,7 +122,7 @@ bool DespotifyWrap::Search(char *searchstring) {
          qDebug() << " search failed: " << despotify_get_error(this->ds);
          return false;
      } else {
-         this->pending_list = search->playlist;
+         this->pending_search = search->playlist->tracks;
          return true;
      }
 
@@ -125,7 +131,7 @@ bool DespotifyWrap::Search(char *searchstring) {
 void DespotifyWrap::PlayNext() {
     /* Check for valid and loaded playlist */
     if(this->lastlist!=NULL){
-        track *t = this->lastlist->tracks;
+        track *t = this->lastlist;
         int offset = 0;
         for (int i=0; i<=current_offset && t; i++) {
             t = t->next;
@@ -142,7 +148,7 @@ void DespotifyWrap::PlayPrev() {
     /* Check for valid and loaded playlist */
     if(this->lastlist!=NULL){
 
-        track *t = this->lastlist->tracks;
+        track *t = this->lastlist;
         int offset = 0;
         if(this->current_offset==0) {
             for (int i=0; t->next; i++) {
@@ -167,3 +173,7 @@ void DespotifyWrap::PlayPrev() {
 void DespotifyWrap::Exit() {
     this->player->Exit();
 }
+
+const char* DespotifyWrap::GetError() {
+    return despotify_get_error(this->ds);
+}
