@@ -15,7 +15,7 @@ int main(int argc, char *argv[])
     if(qfTranslator->load(":/translations/qtify_" + QLocale::system().name())) {
         a.installTranslator(qfTranslator);
     } else {
-        qDebug() << "Not translation for " << QLocale::system().name() << " found, defaulting";
+        qDebug() << "No translation for " << QLocale::system().name() << " found, defaulting";
     }
 
     MainWindow w;
