@@ -1,39 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="fi">
+<!DOCTYPE TS><TS version="1.1" language="fi">
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="515"/>
+        <location filename="../mainwindow.ui" line="823"/>
         <source>Playlist</source>
         <translation type="unfinished">Soittolista</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="370"/>
+        <location filename="../mainwindow.ui" line="672"/>
         <source>Artist</source>
         <translation type="unfinished">Artisti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="375"/>
+        <location filename="../mainwindow.ui" line="571"/>
         <source>Album</source>
         <translation type="unfinished">Albumi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="385"/>
+        <location filename="../mainwindow.ui" line="682"/>
         <source>Rating</source>
         <translation type="unfinished">Lukema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="285"/>
-        <location filename="../mainwindow.ui" line="520"/>
+        <location filename="../mainwindow.ui" line="831"/>
         <source>Search</source>
         <translation type="unfinished">Etsi</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="525"/>
-        <source>Recent</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="150"/>
         <source>Username</source>
@@ -50,44 +43,95 @@
         <translation type="unfinished">Kirjaudu</translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="276"/>
         <source>Show</source>
         <translation type="obsolete">Näytä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="365"/>
+        <location filename="../mainwindow.ui" line="667"/>
         <source>Title</source>
         <translation type="unfinished">Kappaleen nimi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="380"/>
+        <location filename="../mainwindow.ui" line="677"/>
         <source>Duration</source>
         <translation type="unfinished">Kesto</translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="334"/>
         <source>Play/Pause</source>
         <translation type="obsolete">Play/Pause</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="75"/>
+        <location filename="../mainwindow.cpp" line="109"/>
         <source>Incorrect credentials entered
 please try again.</source>
         <translation>Väärä käyttäjänimi tai salasana, yritä uudelleen.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="70"/>
+        <location filename="../mainwindow.cpp" line="104"/>
         <source>Authenticating...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="81"/>
+        <location filename="../mainwindow.cpp" line="113"/>
         <source>Updating playlists...</source>
         <translation>Päivittää soittolistoja</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="102"/>
-        <location filename="../mainwindow.cpp" line="113"/>
+        <location filename="../mainwindow.cpp" line="145"/>
         <source>Select playlist</source>
         <translation>Valitse soittolista</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="243"/>
+        <source>Various artists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="246"/>
+        <source>Tracks: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="215"/>
+        <source>Remember</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="305"/>
+        <source>Song</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="639"/>
+        <source>TextLabel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="662"/>
+        <source>#</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="826"/>
+        <source>Ctrl+P</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="834"/>
+        <source>Ctrl+S</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="839"/>
+        <source>Albums</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="842"/>
+        <source>Ctrl+A</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
